@@ -55,7 +55,7 @@ POSSIBILITY OF SUCH DAMAGE.
 #define NOMINMAX // stupid windows.h confused with min() macros in std namespace
 #endif
 
-#include <miopen/config.h>
+#include <miopen/config.hpp>
 
 #if MIOPEN_BACKEND_OPENCL
 #include <miopen/oclkernel.hpp>
@@ -63,14 +63,15 @@ POSSIBILITY OF SUCH DAMAGE.
 #include <miopen/ocldeviceinfo.hpp>
 #endif
 #include <miopen/db_path.hpp>
-#if MIOPEN_ENABLE_SQLITE
+#if MIOPEN_ENABLE_SQLITE && MIOPEN_USE_SQLITE_PERFDB
 #include <miopen/sqlite_db.hpp>
 #else
 #include <miopen/readonlyramdb.hpp>
 #endif
-#include <miopen/conv/context.hpp>
+#include <miopen/execution_context.hpp>
 #include <miopen/handle.hpp>
 #include <miopen/problem_description.hpp>
+#include <miopen/conv/problem_description.hpp>
 #include <miopen/ramdb.hpp>
 
 #if MIOPEN_BACKEND_OPENCL
@@ -106,12 +107,6 @@ POSSIBILITY OF SUCH DAMAGE.
 #include <cstdint>
 #include <tuple>
 
-using mlo_kernel_info = std::tuple<const std::string,
-                                   const std::string,
-                                   const std::string,
-                                   const std::vector<size_t>,
-                                   const std::vector<size_t>>;
-
 inline int mloLg2(int v)
 {
     auto ret = static_cast<int>(std::ceil(std::log(v) / std::log(2)));
@@ -124,6 +119,8 @@ inline int AlignUp(int val, unsigned step)
     return static_cast<int>(((static_cast<unsigned>(val) + step - 1) / step) * step);
 }
 
+inline size_t AlignUp(size_t val, size_t step) { return (val + step - 1) / step * step; }
+
 namespace miopen {
 
 struct TensorDescriptor;
@@ -139,12 +136,12 @@ class DbTimer;
 
 struct AnyInvokeParams;
 
-#if MIOPEN_ENABLE_SQLITE
+#if MIOPEN_ENABLE_SQLITE && MIOPEN_USE_SQLITE_PERFDB
 using PerformanceDb = DbTimer<MultiFileDb<SQLitePerfDb, SQLitePerfDb, true>>;
 #else
 using PerformanceDb = DbTimer<MultiFileDb<ReadonlyRamDb, RamDb, true>>;
 #endif
-miopen::PerformanceDb GetDb(const miopen::ExecutionContext& ctx);
+MIOPEN_INTERNALS_EXPORT miopen::PerformanceDb GetDb(const miopen::ExecutionContext& ctx);
 
 template <class TTo>
 size_t setTopDescFromMLDesc(int spatial_dims, TTo& to, const TensorDescriptor& tensor)
@@ -184,100 +181,86 @@ auto mloConstruct(T& x) -> decltype(x.mloConstruct(), void())
     x.mloConstruct();
 }
 
-bool IsGemmAplicable(const miopen::ConvolutionContext& ctx,
-                     const miopen::ProblemDescription& problem);
-
-std::vector<miopen::solver::ConvSolution>
-FindAllGemmSolutions(const miopen::ConvolutionContext& ctx,
-                     const miopen::ProblemDescription& problem,
+MIOPEN_INTERNALS_EXPORT std::vector<miopen::solver::ConvSolution>
+FindAllGemmSolutions(const miopen::ExecutionContext& ctx,
+                     const miopen::conv::ProblemDescription& problem,
                      const miopen::AnyInvokeParams& invoke_ctx);
 
-std::vector<std::pair<std::string, size_t>>
-AllGemmWorkspaceSize(const miopen::ConvolutionContext& ctx,
-                     const miopen::ProblemDescription& problem);
+MIOPEN_INTERNALS_EXPORT std::vector<std::pair<std::string, size_t>>
+AllGemmWorkspaceSize(const miopen::ExecutionContext& ctx,
+                     const miopen::conv::ProblemDescription& problem);
 
-std::vector<std::pair<std::string, size_t>>
-AllDirectForwardBackwardDataWorkspaceSize(const miopen::ConvolutionContext& ctx,
-                                          const miopen::ProblemDescription& problem);
+MIOPEN_INTERNALS_EXPORT std::vector<std::pair<std::string, size_t>>
+AllDirectForwardBackwardDataWorkspaceSize(const miopen::ExecutionContext& ctx,
+                                          const miopen::conv::ProblemDescription& problem);
 
-std::vector<std::pair<std::string, size_t>>
-FindAllImplicitGemmWorkspaceSizes(const miopen::ConvolutionContext& ctx,
-                                  const miopen::ProblemDescription& problem);
+MIOPEN_INTERNALS_EXPORT std::vector<std::pair<std::string, size_t>>
+FindAllImplicitGemmWorkspaceSizes(const miopen::ExecutionContext& ctx,
+                                  const miopen::conv::ProblemDescription& problem);
 
-std::vector<std::pair<std::string, size_t>>
-FindAllWinogradWorkspaceSizes(const miopen::ConvolutionContext& ctx,
-                              const miopen::ProblemDescription& problem);
+MIOPEN_INTERNALS_EXPORT std::vector<std::pair<std::string, size_t>>
+FindAllWinogradWorkspaceSizes(const miopen::ExecutionContext& ctx,
+                              const miopen::conv::ProblemDescription& problem);
 
-std::vector<std::pair<std::string, size_t>>
-FindWinogradWrWWorkspaceSizes(const miopen::ConvolutionContext& ctx,
-                              const miopen::ProblemDescription& problem);
+MIOPEN_INTERNALS_EXPORT std::vector<std::pair<std::string, size_t>>
+FindWinogradWrWWorkspaceSizes(const miopen::ExecutionContext& ctx,
+                              const miopen::conv::ProblemDescription& problem);
 
-std::vector<std::pair<std::string, size_t>>
-FindImplicitGemmWrWWorkspaceSizes(const miopen::ConvolutionContext& ctx,
-                                  const miopen::ProblemDescription& problem);
+MIOPEN_INTERNALS_EXPORT std::vector<std::pair<std::string, size_t>>
+FindImplicitGemmWrWWorkspaceSizes(const miopen::ExecutionContext& ctx,
+                                  const miopen::conv::ProblemDescription& problem);
 
-std::vector<std::pair<std::string, size_t>>
-AllDirectBwdWrW2DWorkspaceSize(const miopen::ConvolutionContext& ctx,
-                               const miopen::ProblemDescription& problem);
+MIOPEN_INTERNALS_EXPORT std::vector<std::pair<std::string, size_t>>
+AllDirectBwdWrW2DWorkspaceSize(const miopen::ExecutionContext& ctx,
+                               const miopen::conv::ProblemDescription& problem);
 
-std::vector<std::pair<std::string, size_t>>
-AllFFTForwardBackwardDataWorkspaceSize(const miopen::ConvolutionContext& ctx,
-                                       const miopen::ProblemDescription& problem);
+MIOPEN_INTERNALS_EXPORT std::vector<std::pair<std::string, size_t>>
+AllFFTForwardBackwardDataWorkspaceSize(const miopen::ExecutionContext& ctx,
+                                       const miopen::conv::ProblemDescription& problem);
 
-std::vector<miopen::solver::ConvSolution>
-FindAllDirectSolutions(const miopen::ConvolutionContext& ctx,
-                       const miopen::ProblemDescription& problem,
+MIOPEN_INTERNALS_EXPORT std::vector<miopen::solver::ConvSolution>
+FindAllDirectSolutions(const miopen::ExecutionContext& ctx,
+                       const miopen::conv::ProblemDescription& problem,
                        const miopen::AnyInvokeParams& invoke_ctx);
 
-std::vector<miopen::solver::ConvSolution>
-FindAllImplicitGemmSolutions(const miopen::ConvolutionContext& ctx,
-                             const miopen::ProblemDescription& problem,
+MIOPEN_INTERNALS_EXPORT std::vector<miopen::solver::ConvSolution>
+FindAllImplicitGemmSolutions(const miopen::ExecutionContext& ctx,
+                             const miopen::conv::ProblemDescription& problem,
                              const miopen::AnyInvokeParams& invoke_ctx);
 
-std::vector<miopen::solver::ConvSolution>
-FindAllWinogradSolutions(const miopen::ConvolutionContext& ctx,
-                         const miopen::ProblemDescription& problem,
+MIOPEN_INTERNALS_EXPORT std::vector<miopen::solver::ConvSolution>
+FindAllWinogradSolutions(const miopen::ExecutionContext& ctx,
+                         const miopen::conv::ProblemDescription& problem,
                          const miopen::AnyInvokeParams& invoke_ctx);
 
-std::vector<miopen::solver::ConvSolution>
-FindWinogradWrWAllSolutions(const miopen::ConvolutionContext& ctx,
-                            const miopen::ProblemDescription& problem,
+MIOPEN_INTERNALS_EXPORT std::vector<miopen::solver::ConvSolution>
+FindWinogradWrWAllSolutions(const miopen::ExecutionContext& ctx,
+                            const miopen::conv::ProblemDescription& problem,
                             const miopen::AnyInvokeParams& invoke_ctx);
 
-std::vector<miopen::solver::ConvSolution>
-FindImplicitGemmWrWAllSolutions(const miopen::ConvolutionContext& ctx,
-                                const miopen::ProblemDescription& problem,
+MIOPEN_INTERNALS_EXPORT std::vector<miopen::solver::ConvSolution>
+FindImplicitGemmWrWAllSolutions(const miopen::ExecutionContext& ctx,
+                                const miopen::conv::ProblemDescription& problem,
                                 const miopen::AnyInvokeParams& invoke_ctx);
 
-std::vector<miopen::solver::ConvSolution>
-FindAllBwdWrW2DSolutions(const miopen::ConvolutionContext& ctx,
-                         const miopen::ProblemDescription& problem,
+MIOPEN_INTERNALS_EXPORT std::vector<miopen::solver::ConvSolution>
+FindAllBwdWrW2DSolutions(const miopen::ExecutionContext& ctx,
+                         const miopen::conv::ProblemDescription& problem,
                          const miopen::AnyInvokeParams& invoke_ctx);
 
-std::vector<miopen::solver::ConvSolution>
-FindAllFFTSolutions(const miopen::ConvolutionContext& ctx,
-                    const miopen::ProblemDescription& problem,
+MIOPEN_INTERNALS_EXPORT std::vector<miopen::solver::ConvSolution>
+FindAllFFTSolutions(const miopen::ExecutionContext& ctx,
+                    const miopen::conv::ProblemDescription& problem,
                     const miopen::AnyInvokeParams& invoke_ctx);
 
 struct mlo_construct_base
 {
     mlo_construct_base(miopen::conv::Direction dir) : _problem(dir)
     {
-        _problem.bias              = 0;
-        _problem.pad_w             = 1;
-        _problem.pad_h             = 1;
-        _problem.kernel_size_d     = 3;
-        _problem.kernel_size_w     = 3;
-        _problem.kernel_size_h     = 3;
-        _problem.kernel_stride_w   = 1;
-        _problem.kernel_stride_h   = 1;
-        _problem.kernel_dilation_w = 1;
-        _problem.kernel_dilation_h = 1;
-        _problem.bot_sz            = 0; // bytes
-        _problem.top_sz            = 0; // bytes
-        _problem.weights_sz        = 0; // bytes
-        _problem.bias_sz           = 0; // bytes
-        _problem.group_counts      = 1;
+        _problem.bias    = 0;
+        _problem.bot_sz  = 0; // bytes
+        _problem.top_sz  = 0; // bytes
+        _problem.bias_sz = 0; // bytes
     }
 
     /*
@@ -295,7 +278,7 @@ struct mlo_construct_base
 
 protected:
     miopen::ProblemDescriptionCompatTemporary _problem;
-    miopen::ConvolutionContext _ctx;
+    miopen::ExecutionContext _ctx;
 };
 
 #define MLO_POOLING_OP_AVE 0
